@@ -9,6 +9,7 @@ NULL
 #'
 #' @param ... same arguments as \code{renewalCount()}.
 #'
+#' @keywords internal
 #' @export
 renewal <- function(...) {
     .Deprecated(msg = "Please use 'renewalCount' (the new name of 'renewal')")
@@ -253,10 +254,22 @@ renewal <- function(...) {
 #'     \item{x}{the model matrix (if \code{x = TRUE}).}
 #' }
 #'
+#' @examples
+#' \dontrun{
+#' ## may take some time to run depending on your CPU
+#' data(football)
+#' wei = renewalCount(formula = homeTeamGoals ~ 1,
+#'                     data = football, dist = "weibull", weiMethod = "series_acc",
+#'                     computeHessian = FALSE, control = renewal.control(trace = 0, 
+#'                     method = "nlminb"))
+#' }
 #' @importFrom numDeriv hessian jacobian
 #' @importFrom MASS ginv
 #' @import optimx
 #' @references
+#'
+#' \insertRef{CountrJssArticle}{Countr}
+#' 
 #' \insertRef{cameron2013regression}{Countr}
 #'
 #' @export
@@ -335,7 +348,7 @@ renewalCount <- function(formula, data, subset, na.action, weights, offset,
     Y <- as.integer(round(Y + 0.001))
     if (any(Y < 0))
         stop("invalid dependent variable, negative counts")
-
+# browser()
     ## extract weights and reshape them
     weights <- model.weights(mf)
     if (is.null(weights))
@@ -394,7 +407,24 @@ renewalCount <- function(formula, data, subset, na.action, weights, offset,
     }
 
     ## arrange results by best (largest) value and then fastest
-    fitCount_ <- fitCount_[with(fitCount_, order(-value, xtimes)), ]
+    ## 2019-06-13 patch for issue#1; was:
+    ##     fitCount_ <- fitCount_[with(fitCount_, order(-value, xtimes)), ]
+    ##
+    ##     now sort on 'xtimes' only if it is present.
+    ##
+    ## TODO: Note that column 'xtimes' is not missing on Windows, it is just called 'xtime'.
+    ##       (Need to talk to the maintainer of optimx.)
+    ##
+    ## TODO: it would be better to get rid of the `with()` here...
+    wrk2 <- if("xtimes" %in% names(fitCount_))
+                with(fitCount_, order(-value, xtimes))
+            else if("xtime" %in% names(fitCount_))
+                with(fitCount_, order(-value, xtime))
+            else
+                with(fitCount_, order(-value))
+
+    fitCount_ <- fitCount_[wrk2, ]
+
     fitCount <- fitCount_[1, , drop = FALSE]
     class(fitCount) <- class(fitCount_)
     ## coefficients
