@@ -12,12 +12,12 @@ arma::vec dePril(unsigned xnum, const arma::vec& p0,const  arma::vec& q,
 		 const arma::vec& xj, const unsigned& nsteps) {
 
   // allocate memory
-  unsigned lnt = q.n_elem;
+  // unsigned lnt = q.n_elem;
   arma::vec dfn(nsteps + 1, fill::zeros);
   arma::vec probs(2, fill::zeros);
   double xmp = xnum + 1.0;
   unsigned n, j, nhalf, md, endloop;
-  double fqj, s1, s2, q0n, temp, qinv, xmul, db, term;
+  double s1, s2, temp, qinv, xmul, db, term;
 
   if (xnum == 1)
     dfn = q;
@@ -129,7 +129,7 @@ arma::vec getProbs_dePril_even(unsigned xnum, const Rcpp::List distPars,
   }
 
   if (extrap) {
-    unsigned i8, i4, i2;
+    // unsigned i8, i4, i2;
      unsigned adjust_steps = 0;
     // check if nsteps is enough
     if (nsteps < 2 * xnum) {
@@ -223,7 +223,7 @@ arma::vec getProbs_dePril_even(unsigned xnum, const Rcpp::List distPars,
   }
 
   if (extrap) {
-    unsigned i8, i4, i2;
+    // unsigned i8, i4, i2;
      unsigned adjust_steps = 0;
     // check if nsteps is enough
     if (nsteps < 2 * xnum) {
@@ -311,7 +311,7 @@ arma::vec getProbs_dePril_odd(unsigned xnum, const Rcpp::List distPars,
   vec pdf, p0;
 
   if (extrap) {
-    unsigned i8, i4, i2;
+    // unsigned i8, i4, i2;
      unsigned adjust_steps = 0;
     // check if nsteps is enough
     if (nsteps < 2 * xnum) {
@@ -396,7 +396,7 @@ arma::vec getProbs_dePril_odd(unsigned xnum, const Rcpp::List distPars,
   Rcpp::NumericVector rTemp;
 
   if (extrap) {
-    unsigned i8, i4, i2;
+    // unsigned i8, i4, i2;
      unsigned adjust_steps = 0;
     // check if nsteps is enough
     if (nsteps < 2 * xnum) {
@@ -599,14 +599,15 @@ arma::vec dCount_dePril_vec_bi(arma::Col<unsigned> x, const Rcpp::List distPars,
 			       const unsigned& nsteps = 100,
 			       double time = 1.0, bool extrap = true,
 			       bool logFlag = false) {
-  unsigned lnt = x.n_elem;
+  // 2018-04-12 was: unsigned lnt = x.n_elem;
+  int lnt = x.n_elem;
   arma::vec pbs(lnt, fill::zeros);
   Rcpp::List distParsi;
 
   if (lnt != distPars.size())
     stop("x and distPars should have same length !");
 
-  for (unsigned i = 0; i < lnt; i++) {
+  for (int i = 0; i < lnt; i++) {
     distParsi = distPars[i];
     pbs[i] = dCount_dePril_scalar_bi(x[i], distParsi, dist, nsteps, time,
 				     extrap, logFlag);
@@ -640,7 +641,8 @@ arma::vec dCount_dePril_vec_user(arma::Col<unsigned> x, const Rcpp::List distPar
 				 const unsigned& nsteps = 100,
 				 double time = 1.0, bool extrap = true,
 				 bool logFlag = false) {
-  unsigned lnt = x.n_elem;
+  // 2018-04-12 was: unsigned lnt = x.n_elem;
+  int lnt = x.n_elem;
   arma::vec pbs(lnt, fill::zeros);
   Rcpp::List distParsi;
 
@@ -650,7 +652,7 @@ arma::vec dCount_dePril_vec_user(arma::Col<unsigned> x, const Rcpp::List distPar
   if (lnt != extrapolPars.size())
     stop("x and distPars should have same length !");
 
-  for (unsigned i = 0; i < lnt; i++) {
+  for (int i = 0; i < lnt; i++) {
     distParsi = distPars[i];
     arma::vec extrapolParsi = extrapolPars[i];
     pbs[i] = dCount_dePril_scalar_user(x[i], distParsi, extrapolParsi, survR,
